/**
    @file main.c
    @brief FT9xx UART to GPIO Bridge
**/
/*
 * ============================================================================
 * History
 * =======
 * 2017-03-15 : Created
 *
 * (C) Copyright Bridgetek Pte Ltd
 * ============================================================================
 *
 * This source code ("the Software") is provided by Bridgetek Pte Ltd
 * ("Bridgetek") subject to the licence terms set out
 * http://www.ftdichip.com/FTSourceCodeLicenceTerms.htm ("the Licence Terms").
 * You must read the Licence Terms before downloading or using the Software.
 * By installing or using the Software you agree to the Licence Terms. If you
 * do not agree to the Licence Terms then do not download or use the Software.
 *
 * Without prejudice to the Licence Terms, here is a summary of some of the key
 * terms of the Licence Terms (and in the event of any conflict between this
 * summary and the Licence Terms then the text of the Licence Terms will
 * prevail).
 *
 * The Software is provided "as is".
 * There are no warranties (or similar) in relation to the quality of the
 * Software. You use it at your own risk.
 * The Software should not be used in, or for, any medical device, system or
 * appliance. There are exclusions of Bridgetek liability for certain types of loss
 * such as: special loss or damage; incidental loss or damage; indirect or
 * consequential loss or damage; loss of income; loss of business; loss of
 * profits; loss of revenue; loss of contracts; business interruption; loss of
 * the use of money or anticipated savings; loss of information; loss of
 * opportunity; loss of goodwill or reputation; and/or loss of, damage to or
 * corruption of data.
 * There is a monetary cap on Bridgetek's liability.
 * The Software may have subsequently been amended by another user and then
 * distributed by that other user ("Adapted Software").  If so that user may
 * have additional licence terms that apply to those amendments. However, Bridgetek
 * has no liability in relation to those amendments.
 * ============================================================================
 */

/* INCLUDES ************************************************************************/
#include "shell.h"

/* CONSTANTS ***********************************************************************/
static const int NUM_GPIO = 67;

static const char* HELP_TXT =
        "Usage:"                                                            "\r\n"
        "    H<x>   Set GPIO Pin <x> High"                                  "\r\n"
        "    L<x>   Set GPIO Pin <x> Low"                                   "\r\n"
        "    R<x>   Read GPIO Pin <x>"                                      "\r\n"
        "    I<x>   Set GPIO Pin <x> as an Input"                           "\r\n"
        "    O<x>   Set GPIO Pin <x> as an Output"                          "\r\n"
        "    P<x>   Enable GPIO Pin <x> pullups"                            "\r\n"
        "    p<x>   Disable GPIO Pin <x> pullups"                           "\r\n"
        "    E      Enable Command Echoing"                                 "\r\n"
        "    e      Disable Command Echoing"                                "\r\n"
        "    ?      Display the help text"                                  "\r\n"
        "    #      Reset the device"                                       "\r\n"
        ""                                                                  "\r\n"
        "(C) Copyright 2015, Bridgetek Pte Ltd."  "\r\n";

/* GLOBAL VARIABLES ****************************************************************/

/* LOCAL VARIABLES *****************************************************************/

/* MACROS **************************************************************************/

/* LOCAL FUNCTIONS / INLINES *******************************************************/

void setup(void);
void loop(void);

void gpio_init(void);

void cmdCB(char cmd, int pin);

/* FUNCTIONS ***********************************************************************/

int main(void)
{
    setup();
    for(;;) loop();
    return 0;
}

void setup()
{
    gpio_init();
    shell_init(cmdCB);
}

void loop()
{
    shell_tick();
}

void gpio_init()
{
    int i;
    for(i=0; i<NUM_GPIO; ++i)
    {
        gpio_write(i, 0);
        gpio_dir(i,pad_dir_input);
        gpio_pull(i, pad_pull_none);
    }
}

void cmdCB(char cmd, int pin)
{
    switch(cmd)
    {
        case 'H':
            if (pin != -1)
            {
                gpio_write(pin,1);
            }
            break;

        case 'L':
            if (pin != -1)
            {
                gpio_write(pin,0);
            }
            break;

        case 'R':
            if (pin != -1)
            {
                int8_t val = gpio_read(pin);

                if (val == 0)
                {
                    shell_putsf("0\r\n");
                }
                else if (val == 1)
                {
                    shell_putsf("1\r\n");
                }
            }
            break;

        case 'I':
            if (pin != -1)
            {
                gpio_dir(pin, pad_dir_input);
            }
            break;

        case 'O':
            if (pin != -1)
            {
                gpio_dir(pin, pad_dir_output);
            }
            break;

        case 'P':
            if (pin != -1)
            {
                gpio_pull(pin, pad_pull_pullup);
            }
            break;

        case 'p':
            if (pin != -1)
            {
                gpio_pull(pin, pad_pull_none);
            }
            break;

        case 'E':
            shell_echo(1);
            break;

        case 'e':
            shell_echo(0);
            break;

        case '?':
            shell_putsf(HELP_TXT);
            break;

        case '#':
            setup();
            break;

        default:
            shell_puts("Unknown command '");
            shell_write(cmd);
            shell_puts("'\r\n");
            break;
    }
}
