package com.brtchip.swing;

import java.awt.Cursor;
import java.awt.Desktop;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.io.IOException;
import java.net.URI;
import java.net.URISyntaxException;

import javax.swing.JLabel;

public class JHyperlinkLabel extends JLabel {
	
	public static final long serialVersionUID = 1000L;
	
	/** Construct a hyperlinked label
	 *  
	 * @param url The URL to link to
	 * @param label The text to display
	 */
	public JHyperlinkLabel(final String url, String label) {
		
		// Create a hyperlink
		super("<html><a href=\""+url+"\">"+label+"</a></html>");
		
		// Make it look clickable to the user
		setCursor(Cursor.getPredefinedCursor(Cursor.HAND_CURSOR));
		
		// Make a tooltip to display the address
		setToolTipText(url);
		
		// Add a mouse adapter to make it browse to the url
		addMouseListener(new MouseAdapter() {
			@Override
			public void mouseClicked(MouseEvent e) {				
				super.mouseClicked(e);
				
				if (e.getClickCount() > 0)
				{
					if (Desktop.isDesktopSupported())
					{
						Desktop desktop = Desktop.getDesktop();
						try {
							URI uri = new URI(url);
							desktop.browse(uri);
						} catch (IOException ex) {
							
						} catch (URISyntaxException ex) {
							
						}
					}
				}
			}
		});
		
		
	}
	
	
}
